<?php

namespace Drupal\Tests\browscap\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests import of browscap data.
 *
 * @group browscap
 */
class BrowscapImportTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['browscap'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Tests importing then querying Browscap data.
   */
  public function testImport() {
    $config = \Drupal::config('browscap.settings');
    $versionBefore = $config->get('version');

    $result = \Drupal::service('browscap.importer')->import(new MockBrowscapEndpoint());
    $this->assertTrue($result, 'Import completed successfully.');

    $versionAfter = $config->get('version');
    $this->assertNotEquals($versionBefore, $versionAfter, 'Data version number has changed');

    // Make browscap service call to check that data was loaded.
    $user_agent = 'Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; WOW64; Trident/5.0)';
    $properties = \Drupal::service('browscap')->getBrowser($user_agent);
    $this->assertEquals($properties['browser'], "IE", "Uncached browser is correct.");
    $this->assertEquals($properties['version'], "9.0", "Uncached browser version is correct.");
    $this->assertEquals($properties['platform'], "Win7", "Uncached platform is correct.");

    // Now that the data is cached, try again.
    $properties = \Drupal::service('browscap')->getBrowser($user_agent);
    $this->assertEquals($properties['browser'], "IE", "Cached browser is correct.");
    $this->assertEquals($properties['version'], "9.0", "Cached browser is correct.");
    $this->assertEquals($properties['platform'], "Win7", "Cached browser is correct.");
  }

}
